@@ -145,7 +145,11 @@ class CalicoEtcdWatcher(etcdutils.EtcdWatcher):
     def __init__(self, agent, hostname):
         workload_endpoint_prefix = datamodel_v3._build_key("WorkloadEndpoint",
                                                            "")
-        super(CalicoEtcdWatcher, self).__init__(workload_endpoint_prefix)
+        this_host_prefix = (workload_endpoint_prefix +
+                            hostname.replace('-', '--') +
+                            "-openstack-")
+
+        super(CalicoEtcdWatcher, self).__init__(this_host_prefix)
         self.agent = agent
         self.hostname = hostname
         self.suppress_dnsmasq_updates = False
@@ -572,7 +576,12 @@ class CalicoDhcpAgent(DhcpAgent):
     there are more than a few hundred agents running.
     """
     def __init__(self):
-        hostname = socket.gethostname()
+        try:
+            hostname = cfg.CONF.host
+        except AttributeError:
+            # We get AttributeError (or an exception derived from that) if that
+            # config option does not exist, in an old enough Neutron release.
+            hostname = socket.gethostname()
         super(CalicoDhcpAgent, self).__init__(host=hostname)
 
         # Override settings that Calico's DHCP agent use requires.
